import 'package:feed_plugin/models/poll_option_model.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/widgets/post.dart';
import 'package:flutter/material.dart';
import 'package:inview_notifier_list/inview_notifier_list.dart';

class PostsListView extends StatelessWidget {
  final int likeId = 1;

  final int dislikeId = 3;

  final int saveId = 2;

  const PostsListView({
    Key key,
    @required this.postsList,
    @required this.pollOptionsList,
    @required this.currentUser,
    @required this.loc,
  }) : super(key: key);
  final List<PostModel> postsList;
  final List<PollOptionModel> pollOptionsList;
  final UserModel currentUser;
  final loc;

  @override
  Widget build(BuildContext context) {
    return InViewNotifierList(
        scrollDirection: Axis.vertical,
        initialInViewIds: ['0'],
        isInViewPortCondition:
            (double deltaTop, double deltaBottom, double viewPortDimension) {
          return deltaTop < (0.5 * viewPortDimension) &&
              deltaBottom > (0.5 * viewPortDimension);
        },
        itemCount: 10,
        builder: (BuildContext context, int index) {
          return Container(
              width: double.infinity,
              height: 300.0,
              alignment: Alignment.center,
              margin: EdgeInsets.symmetric(vertical: 50.0),
              child: LayoutBuilder(
                  builder: (BuildContext context, BoxConstraints constraints) {
                return InViewNotifierWidget(
                    id: '$index',
                    builder:
                        (BuildContext context, bool isInView, Widget child) {
                      return ListView.builder(
                        shrinkWrap: true,
                        physics: NeverScrollableScrollPhysics(),
                        itemCount: this.postsList.length,
                        itemBuilder: (BuildContext context, int index) {
                          List<PollOptionModel> pollOptionsListToPost;
                          PostModel post = this.postsList[index];
                          List<String> images =
                              this.postsList[index].attachedUrl.split("*");
                          if (post.pollQuestion != null) {
                            pollOptionsListToPost = [];
                            pollOptionsListToPost = pollOptionsList
                                .where((p) =>
                                    p.pollQuestion.id == post.pollQuestion.id)
                                .toList();
                          }
                          return Container(
                            decoration: BoxDecoration(
                              border: Border(
                                bottom: BorderSide(
                                  width: 15,
                                  color: Color(0xffE8ECEF),
                                ),
                              ),
                            ),
                            child: FeedPost(
                              key: Key("F" + post.id.toString()),
                              postData: post,
                              currentUser: this.currentUser,
                              images: images,
                              likeId: likeId,
                              dislikeId: dislikeId,
                              saveId: saveId,
                              commentsLength: 0,
                              postsList: this.postsList,
                              pollOptionsList: pollOptionsListToPost,
                              generalPollOptionsList: pollOptionsList,
                              loc: this.loc,
                            ),
                          );
                        },
                      );
                    });
              }));
        });
  }
}
